// Copyright 2023 Esri
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.


import SwiftUI

import ArcGIS

struct ContentView: View {

    @State private var scene: ArcGIS.Scene = {
        let scene = Scene(basemapStyle: .arcGISImageryStandard)

        // Create an elevation source to show relief in the scene.
        let worldElevationServiceURL = URL(string: "https://elevation3d.arcgis.com/arcgis/rest/services/WorldElevation3D/Terrain3D/ImageServer")!
        let elevationSource = ArcGISTiledElevationSource(url: worldElevationServiceURL)

        // Create a Surface with the elevation data.
        let surface = Surface()
        surface.addElevationSource(elevationSource)

        // Add an exaggeration factor to increase the 3D effect of the elevation.
        surface.elevationExaggeration = 2.5

        // Apply the surface to the scene.
        scene.baseSurface = surface

        // Create a point that defines the observer's (camera) initial location in the scene.
        // The point defines a longitude, latitude, and altitude of the initial camera location.
        let point = Point(x: -118.804, y: 34.027, z: 5330.0, spatialReference: .wgs84)

        // Create a Camera uing the point, the direction the camera should face (heading), and its pitch and roll (rotation and tilt).
        let camera = Camera(location: point, heading: 355.0, pitch: 72.0, roll: 0)

        // Set an initial viewpoint for the scene using the camera and observation point.
        scene.initialViewpoint = Viewpoint(boundingGeometry: point, camera: camera)

        return scene
    }()

    var body: some View {

        SceneView(scene: scene)

    }

}


